@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bulletin_board.c,v 1.37.2.3 2004/05/24 10:43:51 fuyu Exp $
+ * $Id: ochusha_bulletin_board.c,v 1.37.2.5 2004/06/05 12:55:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -484,7 +484,7 @@ ochusha_bulletin_board_process_board_move(OchushaBulletinBoard *board,
 	       ochusha_bulletin_board_get_server(board),
 	       ochusha_bulletin_board_get_base_path(board),
 	       ochusha_bulletin_board_get_id(board));
-      tmp_pos = strstr(tmp_path, "/" OCHUSHA_THREADLIST_XML);
+      tmp_pos = strstr(tmp_path, "/threadlist.xml");
       *tmp_pos = '\0';
       if (mkdir_p(tmp_path))
 	{
@@ -499,14 +499,14 @@ ochusha_bulletin_board_process_board_move(OchushaBulletinBoard *board,
 
   if (old_path != NULL)
     {
-      tmp_pos = strstr(old_path, "/" OCHUSHA_THREADLIST_XML);
+      tmp_pos = strstr(old_path, "/threadlist.xml");
       tmp_pos[1] = 'd';
       tmp_pos[2] = 'a';
       tmp_pos[3] = 't';
       tmp_pos[4] = '\0';
       if (stat(old_path, &sb) == 0)
 	{
-	  tmp_pos = strstr(new_path, "/" OCHUSHA_THREADLIST_XML);
+	  tmp_pos = strstr(new_path, "/threadlist.xml");
 	  tmp_pos[1] = 'd';
 	  tmp_pos[2] = 'a';
 	  tmp_pos[3] = 't';
@@ -1447,6 +1447,10 @@ write_bbs_thread(gpointer data, gpointer user_data)
   WriteThreadlistArgs *args = (WriteThreadlistArgs *)user_data;
   gzFile threadlist_xml = args->threadlist_xml;
 
+  if (thread->flags & OCHUSHA_BBS_THREAD_DAT_DROPPED
+      && ochusha_bbs_thread_get_number_of_responses_read(thread) == 0)
+    return;
+
   gzprintf(threadlist_xml, "    <thread>\n");
 
   g_signal_emit_by_name(G_OBJECT(thread),
