@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.40.2.2 2004/05/24 10:03:04 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.40.2.3 2004/06/05 14:17:14 fuyu Exp $
  */
 
 #include "config.h"
@@ -32,6 +32,7 @@
 #include "ochusha.h"
 #include "ochusha_bbs_table.h"
 #include "ochusha_board_2ch.h"
+#include "ochusha_board_jbbs.h"
 #include "ochusha_thread_2ch.h"
 #include "ochusha_utils_2ch.h"
 
@@ -758,9 +759,17 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	      return FALSE;	/* Out of memory */
 	    }
 
-	  board = ochusha_board_2ch_new(name, url);
 	  if (is_machibbs)
-	    board->bbs_type = OCHUSHA_BBS_TYPE_MACHIBBS;
+	    {
+	      board = ochusha_board_jbbs_new(name, url);
+	      board->bbs_type = OCHUSHA_BBS_TYPE_MACHIBBS;
+	      ochusha_bulletin_board_set_base_url(board, url);	/* ۤ */
+	    }
+	  else
+	    {
+	      board = ochusha_board_2ch_new(name, url);
+	      board->bbs_type = OCHUSHA_BBS_TYPE_2CH;
+	    }
 
 #if GUESS_2CH_BOARD_URL
 	  id = ochusha_bulletin_board_get_id(board);
@@ -772,6 +781,14 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	      goto search_next;
 	    }
 #endif
+	  if (board_by_name != NULL)
+	    {
+	      if (is_machibbs
+		  && board_by_name->bbs_type != OCHUSHA_BBS_TYPE_MACHIBBS)
+		board_by_name = NULL;
+	      else if (board_by_name->bbs_type != OCHUSHA_BBS_TYPE_2CH)
+		board_by_name = NULL;
+	    }
 
 	  if (board_by_name != NULL && board_moved_callback != NULL)
 	    {
